@@ -21,15 +21,13 @@
 
 dbTableInfo <- function(conn, name, allinfo = FALSE) {
     ## only check if valid (error if not)
-    name.fix <- dbTableNameFix(name)
-    #add public if length == 1
-    if (length(name) == 1) {name<-c("public",name)}
+    name <- dbTableNameFix(conn,name,as.identifier=FALSE)
     if (allinfo) {
         cols <- "*"
     } else {
         cols <- "column_name,data_type,is_nullable,character_maximum_length"
     }
-    df <- dbGetQuery(conn, paste0("SELECT ", cols, " FROM information_schema.columns\nWHERE table_schema = '",
-        name[1], "' AND table_name = '", name[2], "';"))
+    df <- dbGetQuery(conn, paste0("SELECT ", cols, " FROM information_schema.columns\nWHERE table_schema = ",
+        DBI::dbQuoteString(conn,name[1]), " AND table_name = ", DBI::dbQuoteString(conn,name[2]), ";"))
     return(df)
 }
\ No newline at end of file
