@@ -30,11 +30,11 @@ pgListGeom <- function(conn, display = TRUE, exec = TRUE) {
     ##     f_table_name AS table_name,
     ##     f_geometry_column AS geom_column,
     ##     type AS geometry_type
-    ## FROM public.geometry_columns;
+    ## FROM geometry_columns;
     ## --
     tmp.query <- paste("SELECT", "    f_table_schema AS schema_name,",
         "    f_table_name AS table_name,", "    f_geometry_column AS geom_column,",
-        "    type AS geometry_type", "FROM public.geometry_columns;",
+        "    type AS geometry_type", "FROM geometry_columns;",
         sep = "\n")
     ## Display the query
     if (display) {
